translate.storage.pocommon.pofile

Package translate :: Package storage :: Module pocommon :: Class pofile |
[hide private]
[frames] | no frames]

# Class pofile

source code

Nested Classes | [hide private]
Inherited from `base.TranslationStore`: `UnitClass`

Instance Methods | [hide private]
__init__(self, inputfile=None, encoding=None) Constructs a blank TranslationStore. | source code
Inherited from `poheader.poheader`: `getheaderplural`, `gettargetlanguage`, `header`, `makeheader`, `makeheaderdict`, `mergeheaders`, `parseheader`, `settargetlanguage`, `updatecontributor`, `updateheader`, `updateheaderplural` Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `__str__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `findid`, `findunit`, `findunits`, `getids`, `getsourcelanguage`, `getunits`, `isempty`, `makeindex`, `parse`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setsourcelanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
| Name = `_("Gettext PO file")` The human usable name of this store type
| Mimetypes = `["text/x-gettext-catalog", "text/x-gettext-transla`...`` A list of MIME types associated with this store type
| Extensions = `["po", "pot"]` A list of file extentions associated with this store type
Inherited from `poheader.poheader`: `header_order`, `x_generator` Inherited from `base.TranslationStore`: `suggestions_in_format` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, inputfile=None, encoding=None) (Constructor) | source code
Constructs a blank TranslationStore. Overrides: object.__init__ (inherited documentation)

Class Variable Details | [hide private]

  ### Mimetypes A list of MIME types associated with this store type Value:
      ["text/x-gettext-catalog", "text/x-gettext-translation", "text/x-po",
      "text/x-pot"]